==> jdk-11.0.18.10.1p0v0.tgz: jdk.localedata/sun/text/resources/cldr/ext/FormatData_ce.java <==
/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.text.resources.cldr.ext;

import java.util.ListResourceBundle;

public class FormatData_ce extends ListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] metaValue_MonthNames = new String[] {
               "\u044f\u043d\u0432\u0430\u0440\u044c",
               "\u0444\u0435\u0432\u0440\u0430\u043b\u044c",
               "\u043c\u0430\u0440\u0442",
               "\u0430\u043f\u0440\u0435\u043b\u044c",
               "\u043c\u0430\u0439",
               "\u0438\u044e\u043d\u044c",
               "\u0438\u044e\u043b\u044c",
               "\u0430\u0432\u0433\u0443\u0441\u0442",
               "\u0441\u0435\u043d\u0442\u044f\u0431\u0440\u044c",
               "\u043e\u043a\u0442\u044f\u0431\u0440\u044c",
               "\u043d\u043e\u044f\u0431\u0440\u044c",
               "\u0434\u0435\u043a\u0430\u0431\u0440\u044c",
               "",
            };
        final String[] metaValue_MonthAbbreviations = new String[] {
               "\u044f\u043d\u0432",
               "\u0444\u0435\u0432",
               "\u043c\u0430\u0440",
               "\u0430\u043f\u0440",
               "\u043c\u0430\u0439",
               "\u0438\u044e\u043d",
               "\u0438\u044e\u043b",
               "\u0430\u0432\u0433",
               "\u0441\u0435\u043d",
               "\u043e\u043a\u0442",
               "\u043d\u043e\u044f",
               "\u0434\u0435\u043a",
               "",
            };
        final String[] metaValue_MonthNarrows = new String[] {
               "\u042f",
               "\u0424",
               "\u041c",
               "\u0410",
               "\u041c",
               "\u0418",
               "\u0418",
               "\u0410",
               "\u0421",
               "\u041e",
               "\u041d",
               "\u0414",
               "",
            };
        final String[] metaValue_DayNames = new String[] {
               "\u043a\u04c0\u0438\u0440\u0430",
               "\u043e\u0440\u0448\u043e\u0442",
               "\u0448\u0438\u043d\u0430\u0440\u0430",
               "\u043a\u0445\u0430\u0430\u0440\u0430",
               "\u0435\u0430\u0440\u0430",
               "\u043f\u04c0\u0435\u0440\u0430\u0441\u043a\u0430",
               "\u0448\u0443\u043e\u0442",
            };
        final String[] metaValue_DayAbbreviations = new String[] {
               "\u043a\u04c0\u0438",
               "\u043e\u0440",
               "\u0448\u0438",
               "\u043a\u0445\u0430",
               "\u0435\u0430",
               "\u043f\u04c0\u0435",
               "\u0448\u0443\u043e",
            };
        final String[] metaValue_QuarterNames = new String[] {
               "1-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
               "2-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
               "3-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
               "4-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
            };
        final String[] metaValue_QuarterAbbreviations = new String[] {
               "1-\u0433\u04c0\u0430 \u043a\u0432.",
               "2-\u0433\u04c0\u0430 \u043a\u0432.",
               "3-\u0433\u04c0\u0430 \u043a\u0432.",
               "4-\u0433\u04c0\u0430 \u043a\u0432.",
            };
        final String[] metaValue_Eras = new String[] {
               "\u0432. \u044d. \u0442\u04c0. \u044f",
               "\u0432. \u044d",
            };
        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
               "1",
               "2",
               "3",
               "4",
            };
        final String metaValue_calendarname_gregorian = "\u0433\u0440\u0438\u0433\u043e\u0440\u0438\u0430\u043d\u0430\u043d";
        final Object[][] data = new Object[][] {
            { "MonthNames", metaValue_MonthNames },
            { "field.year", "\u0448\u043e" },
            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
            { "standalone.DayNarrows",
                new String[] {
                    "\u043a\u04c0",
                    "\u043e",
                    "\u0448",
                    "\u043a\u0445",
                    "\u0435",
                    "\u043f\u04c0",
                    "\u0448",
                }
            },
            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.QuarterNames", metaValue_QuarterNames },
            { "islamic.DayNarrows", metaValue_DayAbbreviations },
            { "field.zone", "\u0441\u0430\u0445\u044c\u0442\u0430\u043d \u0430\u0441\u0430" },
            { "roc.MonthNarrows", metaValue_MonthNarrows },
            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "narrow.Eras", metaValue_Eras },
            { "calendarname.japanese", "\u044f\u043f\u043e\u043d\u0438\u0439\u043d" },
            { "Eras", metaValue_Eras },
            { "japanese.MonthNames", metaValue_MonthNames },
            { "roc.DayNames", metaValue_DayNames },
            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "islamic.QuarterNames", metaValue_QuarterNames },
            { "long.Eras",
                new String[] {
                    "\u04c0\u0438\u0439\u0441\u0430 \u043f\u0430\u0439\u0445\u0430\u043c\u0430\u0440 \u0432\u0438\u043d\u0430 \u0434\u0435 \u043a\u0445\u0430\u0447\u0430\u043b\u0435",
                    "\u04c0\u0438\u0439\u0441\u0430 \u043f\u0430\u0439\u0445\u0430\u043c\u0430\u0440 \u0432\u0438\u043d\u0430 \u0434\u0438\u0439\u043d\u0430\u0445\u044c \u0434\u0443\u044c\u0439\u043d\u0430",
                }
            },
            { "islamic.DayNames", metaValue_DayNames },
            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "field.weekday", "\u043a\u04c0\u0438\u0440\u0430\u043d\u0430\u043d \u0434\u0435" },
            { "buddhist.MonthNames", metaValue_MonthNames },
            { "latn.NumberElements",
                new String[] {
                    ".",
                    ",",
                    ";",
                    "%",
                    "0",
                    "#",
                    "-",
                    "E",
                    "\u2030",
                    "\u221e",
                    "\u0422\u0435\u0440\u0445\u044c\u0430\u0448\u00a0\u0434\u0430\u0446",
                }
            },
            { "MonthNarrows", metaValue_MonthNarrows },
            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "buddhist.DayNames", metaValue_DayNames },
            { "field.minute", "\u043c\u0438\u043d\u043e\u0442" },
            { "field.era", "\u043c\u0443\u0440" },
            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
            { "field.dayperiod", "\u0434\u0435\u043b\u043a\u044a\u0430\u043b \u0442\u04c0\u0435\u0445\u044c\u0430" },
            { "standalone.MonthNarrows", metaValue_MonthNarrows },
            { "japanese.QuarterNames", metaValue_QuarterNames },
            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "japanese.DayNames", metaValue_DayNames },
            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
            { "DayNames", metaValue_DayNames },
            { "field.month", "\u0431\u0443\u0442\u0442" },
            { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
            { "roc.MonthNames", metaValue_MonthNames },
            { "field.week", "\u043a\u04c0\u0438\u0440\u0430" },
            { "DayAbbreviations", metaValue_DayAbbreviations },
            { "DayNarrows", metaValue_DayAbbreviations },
            { "NumberPatterns",
                new String[] {
                    "#,##0.###",
                    "#,##0.00\u00a0\u00a4",
                    "#,##0\u00a0%",
                }
            },
            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
            { "buddhist.QuarterNames", metaValue_QuarterNames },
            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
            { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u0430\u043d" },
            { "roc.DayNarrows", metaValue_DayAbbreviations },
            { "calendarname.gregorian", metaValue_calendarname_gregorian },
            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
            { "MonthAbbreviations", metaValue_MonthAbbreviations },
            { "standalone.DayNames", metaValue_DayNames },
            { "field.hour", "\u0441\u0430\u0445\u044c\u0442" },
            { "standalone.MonthNames", metaValue_MonthNames },
            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "buddhist.DayNarrows", metaValue_DayAbbreviations },
            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
            { "japanese.DayNarrows", metaValue_DayAbbreviations },
            { "QuarterNames", metaValue_QuarterNames },
            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "standalone.QuarterNames", metaValue_QuarterNames },
            { "japanese.MonthNarrows", metaValue_MonthNarrows },
            { "calendarname.gregory", metaValue_calendarname_gregorian },
        };
        return data;
    }
}

==> jdk-17.0.17.10.1p0v0.tgz: jdk.localedata/sun/text/resources/cldr/ext/FormatData_ce.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.text.resources.cldr.ext;

import java.util.ListResourceBundle;

public class FormatData_ce extends ListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] metaValue_MonthNames = new String[] {
               "\u044f\u043d\u0432\u0430\u0440\u044c",
               "\u0444\u0435\u0432\u0440\u0430\u043b\u044c",
               "\u043c\u0430\u0440\u0442",
               "\u0430\u043f\u0440\u0435\u043b\u044c",
               "\u043c\u0430\u0439",
               "\u0438\u044e\u043d\u044c",
               "\u0438\u044e\u043b\u044c",
               "\u0430\u0432\u0433\u0443\u0441\u0442",
               "\u0441\u0435\u043d\u0442\u044f\u0431\u0440\u044c",
               "\u043e\u043a\u0442\u044f\u0431\u0440\u044c",
               "\u043d\u043e\u044f\u0431\u0440\u044c",
               "\u0434\u0435\u043a\u0430\u0431\u0440\u044c",
               "",
            };
        final String[] metaValue_MonthAbbreviations = new String[] {
               "\u044f\u043d\u0432",
               "\u0444\u0435\u0432",
               "\u043c\u0430\u0440",
               "\u0430\u043f\u0440",
               "\u043c\u0430\u0439",
               "\u0438\u044e\u043d",
               "\u0438\u044e\u043b",
               "\u0430\u0432\u0433",
               "\u0441\u0435\u043d",
               "\u043e\u043a\u0442",
               "\u043d\u043e\u044f",
               "\u0434\u0435\u043a",
               "",
            };
        final String[] metaValue_MonthNarrows = new String[] {
               "\u042f",
               "\u0424",
               "\u041c",
               "\u0410",
               "\u041c",
               "\u0418",
               "\u0418",
               "\u0410",
               "\u0421",
               "\u041e",
               "\u041d",
               "\u0414",
               "",
            };
        final String[] metaValue_DayNames = new String[] {
               "\u043a\u04c0\u0438\u0440\u0430",
               "\u043e\u0440\u0448\u043e\u0442",
               "\u0448\u0438\u043d\u0430\u0440\u0430",
               "\u043a\u0445\u0430\u0430\u0440\u0430",
               "\u0435\u0430\u0440\u0430",
               "\u043f\u04c0\u0435\u0440\u0430\u0441\u043a\u0430",
               "\u0448\u0443\u043e\u0442",
            };
        final String[] metaValue_DayAbbreviations = new String[] {
               "\u043a\u04c0\u0438",
               "\u043e\u0440",
               "\u0448\u0438",
               "\u043a\u0445\u0430",
               "\u0435\u0430",
               "\u043f\u04c0\u0435",
               "\u0448\u0443\u043e",
            };
        final String[] metaValue_QuarterNames = new String[] {
               "1-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
               "2-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
               "3-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
               "4-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
            };
        final String[] metaValue_QuarterAbbreviations = new String[] {
               "1-\u0433\u04c0\u0430 \u043a\u0432.",
               "2-\u0433\u04c0\u0430 \u043a\u0432.",
               "3-\u0433\u04c0\u0430 \u043a\u0432.",
               "4-\u0433\u04c0\u0430 \u043a\u0432.",
            };
        final String[] metaValue_Eras = new String[] {
               "\u0432. \u044d. \u0442\u04c0. \u044f",
               "\u0432. \u044d",
            };
        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
               "1",
               "2",
               "3",
               "4",
            };
        final String metaValue_calendarname_gregorian = "\u0433\u0440\u0438\u0433\u043e\u0440\u0438\u0430\u043d\u0430\u043d";
        final Object[][] data = new Object[][] {
            { "MonthNames", metaValue_MonthNames },
            { "field.year", "\u0448\u043e" },
            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
            { "standalone.DayNarrows",
                new String[] {
                    "\u043a\u04c0",
                    "\u043e",
                    "\u0448",
                    "\u043a\u0445",
                    "\u0435",
                    "\u043f\u04c0",
                    "\u0448",
                }
            },
            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.QuarterNames", metaValue_QuarterNames },
            { "islamic.DayNarrows", metaValue_DayAbbreviations },
            { "field.zone", "\u0441\u0430\u0445\u044c\u0442\u0430\u043d \u0430\u0441\u0430" },
            { "roc.MonthNarrows", metaValue_MonthNarrows },
            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "narrow.Eras", metaValue_Eras },
            { "calendarname.japanese", "\u044f\u043f\u043e\u043d\u0438\u0439\u043d" },
            { "Eras", metaValue_Eras },
            { "japanese.MonthNames", metaValue_MonthNames },
            { "roc.DayNames", metaValue_DayNames },
            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "islamic.QuarterNames", metaValue_QuarterNames },
            { "long.Eras",
                new String[] {
                    "\u04c0\u0438\u0439\u0441\u0430 \u043f\u0430\u0439\u0445\u0430\u043c\u0430\u0440 \u0432\u0438\u043d\u0430 \u0434\u0435 \u043a\u0445\u0430\u0447\u0430\u043b\u0435",
                    "\u04c0\u0438\u0439\u0441\u0430 \u043f\u0430\u0439\u0445\u0430\u043c\u0430\u0440 \u0432\u0438\u043d\u0430 \u0434\u0438\u0439\u043d\u0430\u0445\u044c \u0434\u0443\u044c\u0439\u043d\u0430",
                }
            },
            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
            { "islamic.DayNames", metaValue_DayNames },
            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "field.weekday", "\u043a\u04c0\u0438\u0440\u0430\u043d\u0430\u043d \u0434\u0435" },
            { "buddhist.MonthNames", metaValue_MonthNames },
            { "latn.NumberElements",
                new String[] {
                    ".",
                    ",",
                    ";",
                    "%",
                    "0",
                    "#",
                    "-",
                    "E",
                    "\u2030",
                    "\u221e",
                    "\u0422\u0435\u0440\u0445\u044c\u0430\u0448\u00a0\u0434\u0430\u0446",
                    "",
                    "",
                }
            },
            { "MonthNarrows", metaValue_MonthNarrows },
            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "buddhist.DayNames", metaValue_DayNames },
            { "field.minute", "\u043c\u0438\u043d\u043e\u0442" },
            { "field.era", "\u043c\u0443\u0440" },
            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
            { "field.dayperiod", "\u0434\u0435\u043b\u043a\u044a\u0430\u043b \u0442\u04c0\u0435\u0445\u044c\u0430" },
            { "standalone.MonthNarrows", metaValue_MonthNarrows },
            { "japanese.QuarterNames", metaValue_QuarterNames },
            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "japanese.DayNames", metaValue_DayNames },
            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
            { "DayNames", metaValue_DayNames },
            { "field.month", "\u0431\u0443\u0442\u0442" },
            { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
            { "roc.MonthNames", metaValue_MonthNames },
            { "field.week", "\u043a\u04c0\u0438\u0440\u0430" },
            { "DayAbbreviations", metaValue_DayAbbreviations },
            { "DayNarrows", metaValue_DayAbbreviations },
            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
            { "buddhist.QuarterNames", metaValue_QuarterNames },
            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
            { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u0430\u043d" },
            { "roc.DayNarrows", metaValue_DayAbbreviations },
            { "short.CompactNumberPatterns",
                new String[] {
                    "",
                    "",
                    "",
                    "{one:0\u00a0\u044d\u0437\u0430\u0440 other:0\u00a0\u044d\u0437\u0430\u0440}",
                    "{one:00\u00a0\u044d\u0437\u0430\u0440 other:00\u00a0\u044d\u0437\u0430\u0440}",
                    "{one:000\u00a0\u044d\u0437\u0430\u0440 other:000\u00a0\u044d\u0437\u0430\u0440}",
                    "{one:0\u00a0\u043c\u043b\u043d other:0\u00a0\u043c\u043b\u043d}",
                    "{one:00\u00a0\u043c\u043b\u043d other:00\u00a0\u043c\u043b\u043d}",
                    "{one:000\u00a0\u043c\u043b\u043d other:000\u00a0\u043c\u043b\u043d}",
                    "{one:0\u00a0\u043c\u043b\u0440\u0434 other:0\u00a0\u043c\u043b\u0440\u0434}",
                    "{one:00\u00a0\u043c\u043b\u0440\u0434 other:00\u00a0\u043c\u043b\u0440\u0434}",
                    "{one:000\u00a0\u043c\u043b\u0440\u0434 other:000\u00a0\u043c\u043b\u0440\u0434}",
                    "{one:0\u00a0\u0442\u0440\u043b\u043d other:0\u00a0\u0442\u0440\u043b\u043d}",
                    "{one:00\u00a0\u0442\u0440\u043b\u043d other:00\u00a0\u0442\u0440\u043b\u043d}",
                    "{one:000\u00a0\u0442\u0440\u043b\u043d other:000\u00a0\u0442\u0440\u043b\u043d}",
                }
            },
            { "calendarname.gregorian", metaValue_calendarname_gregorian },
            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
            { "MonthAbbreviations", metaValue_MonthAbbreviations },
            { "standalone.DayNames", metaValue_DayNames },
            { "PluralRules", "one:n = 1" },
            { "field.hour", "\u0441\u0430\u0445\u044c\u0442" },
            { "standalone.MonthNames", metaValue_MonthNames },
            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "latn.NumberPatterns",
                new String[] {
                    "#,##0.###",
                    "#,##0.00\u00a0\u00a4",
                    "#,##0\u00a0%",
                    "#,##0.00\u00a0\u00a4",
                }
            },
            { "long.CompactNumberPatterns",
                new String[] {
                    "",
                    "",
                    "",
                    "{one:0' '\u044d\u0437\u0430\u0440 other:0' '\u044d\u0437\u0430\u0440}",
                    "{one:00' '\u044d\u0437\u0430\u0440 other:00' '\u044d\u0437\u0430\u0440}",
                    "{one:000' '\u044d\u0437\u0430\u0440 other:000' '\u044d\u0437\u0430\u0440}",
                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
                    "{one:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
                    "{one:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
                    "{one:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
                }
            },
            { "buddhist.DayNarrows", metaValue_DayAbbreviations },
            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
            { "japanese.DayNarrows", metaValue_DayAbbreviations },
            { "QuarterNames", metaValue_QuarterNames },
            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "standalone.QuarterNames", metaValue_QuarterNames },
            { "japanese.MonthNarrows", metaValue_MonthNarrows },
            { "calendarname.gregory", metaValue_calendarname_gregorian },
        };
        return data;
    }
}
